use crate::cli::Cli;

/// Mqtt configuration
pub struct MqttConfig {
    /// Mqtt broker host
    pub broker: String,
    /// Mqtt broker port
    pub port: u16,
    /// Mqtt user name with publishing rights
    pub user: String,
    /// Password for the publishing userr
    pub password: String,
}

/// Application configuration.
pub struct Config {
    /// Update interval in seconds
    pub interval: u64,
    /// Database connection string where timestamps are stored (SQLite, Postgres or MySql)
    pub connection: String,
    /// Mqtt Configuration
    pub mqtt: MqttConfig,
}

impl From<Cli> for Config {
    fn from(value: Cli) -> Self {
        Self {
            interval: value.interval,
            connection: value.connection,
            mqtt: MqttConfig {
                broker: value.mqtt_broker,
                port: value.mqtt_port,
                user: value.mqtt_user,
                password: value.mqtt_password,
            },
        }
    }
}
