use serde::{Deserialize, Serialize};

use crate::json::{self, contact::Contact, description::Description, title::Title};

#[derive(Serialize, Deserialize, Debug, Clone)]
pub struct Text {
    pub origin: Option<String>,
    pub translated: String,
}

impl From<Title> for Text {
    fn from(value: Title) -> Self {
        Self {
            origin: value.title_gtrans_origin,
            translated: value.title,
        }
    }
}

impl From<Description> for Text {
    fn from(value: Description) -> Self {
        Self {
            origin: value.description_gtrans_origin,
            translated: value.description,
        }
    }
}

impl From<json::text::Text> for Text {
    fn from(value: json::text::Text) -> Self {
        Self {
            origin: value.text_origin,
            translated: value.text,
        }
    }
}

impl From<Contact> for Text {
    fn from(value: Contact) -> Self {
        Self {
            origin: value.contact_origin,
            translated: value.contact,
        }
    }
}
