use serde::{Deserialize, Serialize};
use time::PrimitiveDateTime;

use super::{
    area::Area, contact::Contact, description::Description, image::Image,
    image_description::ImageDescription, image_title::ImageTitle, link::Link, text::Text,
    title::Title,
};

#[derive(Debug, Clone, Serialize, Deserialize)]
#[serde(rename_all = "camelCase")]
pub struct Alert {
    pub identifier: String,
    pub gtrans_origin: Option<String>,
    #[serde(deserialize_with = "super::datetime::deserialize_alert")]
    pub sent: PrimitiveDateTime,
    pub title: Title,
    pub description: Description,
    pub nation_wide: bool,
    pub banner: bool,
    pub instructions: Vec<Text>,
    pub sender: String,
    pub publisher_name: Option<String>,
    pub link: Option<String>,
    pub links: Vec<Link>,
    pub contact: Contact,
    pub event: String,
    pub all_clear: bool,
    pub severity: String,
    pub test_alert: bool,
    pub technical_test_alert: bool,
    #[serde(deserialize_with = "super::datetime::deserialize_alert")]
    pub publish_date: PrimitiveDateTime,
    pub areas: Vec<Area>,
    pub images: Vec<Image>,
    pub image_titles: Vec<ImageTitle>,
    pub image_descriptions: Vec<ImageDescription>,
    pub event_icon_path: String,
    pub reference: String,
}
